@@ -38,6 +38,7 @@ from .type_defs import (
     GetBackendJobResponseTypeDef,
     GetBackendResponseTypeDef,
     GetTokenResponseTypeDef,
+    ImportBackendAuthResponseTypeDef,
     ListBackendJobsResponseTypeDef,
     LoginAuthConfigReqObjTypeDef,
     RemoveAllBackendsResponseTypeDef,
@@ -76,7 +77,7 @@ class Exceptions:
 
 class AmplifyBackendClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html)
     """
 
@@ -85,7 +86,9 @@ class AmplifyBackendClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#can_paginate)
         """
 
@@ -93,7 +96,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, TargetEnvironmentName: str
     ) -> CloneBackendResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        This operation clones an existing backend.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#clone_backend)
         """
 
@@ -107,7 +112,9 @@ class AmplifyBackendClient:
         ResourceName: str = None
     ) -> CreateBackendResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        This operation creates a backend for an Amplify app.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend)
         """
 
@@ -120,7 +127,9 @@ class AmplifyBackendClient:
         ResourceName: str
     ) -> CreateBackendAPIResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        Creates a new backend API resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_api)
         """
 
@@ -133,7 +142,9 @@ class AmplifyBackendClient:
         ResourceName: str
     ) -> CreateBackendAuthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        Creates a new backend authentication resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_auth)
         """
 
@@ -141,13 +152,18 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendManagerAppId: str = None
     ) -> CreateBackendConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        Creates a config object for a backend.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_config)
         """
 
     def create_token(self, *, AppId: str) -> CreateTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        Generates a one-time challenge code to authenticate a user into your Amplify
+        Admin UI.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_token)
         """
 
@@ -155,7 +171,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str
     ) -> DeleteBackendResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        Removes an existing environment from your Amplify project.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend)
         """
 
@@ -168,7 +186,9 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
     ) -> DeleteBackendAPIResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        Deletes an existing backend API resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_api)
         """
 
@@ -176,13 +196,17 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> DeleteBackendAuthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        Deletes an existing backend authentication resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_auth)
         """
 
     def delete_token(self, *, AppId: str, SessionId: str) -> DeleteTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        Deletes the challenge token based on the given appId and sessionId.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_token)
         """
 
@@ -190,7 +214,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GenerateBackendAPIModelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        Generates a model schema for an existing backend API resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_backend_api_models)
         """
 
@@ -202,7 +228,9 @@ class AmplifyBackendClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_presigned_url)
         """
 
@@ -210,7 +238,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str = None
     ) -> GetBackendResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        Provides project-level details for your Amplify UI project.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend)
         """
 
@@ -223,7 +253,9 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
     ) -> GetBackendAPIResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        Gets the details for a backend API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api)
         """
 
@@ -231,7 +263,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAPIModelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        Generates a model schema for existing backend API resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api_models)
         """
 
@@ -239,7 +273,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAuthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        Gets a backend auth details.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_auth)
         """
 
@@ -247,16 +283,37 @@ class AmplifyBackendClient:
         self, *, AppId: str, BackendEnvironmentName: str, JobId: str
     ) -> GetBackendJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        Returns information about a specific job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_job)
         """
 
     def get_token(self, *, AppId: str, SessionId: str) -> GetTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        Gets the challenge token based on the given appId and sessionId.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_token)
         """
 
+    def import_backend_auth(
+        self,
+        *,
+        AppId: str,
+        BackendEnvironmentName: str,
+        NativeClientId: str,
+        UserPoolId: str,
+        WebClientId: str,
+        IdentityPoolId: str = None
+    ) -> ImportBackendAuthResponseTypeDef:
+        """
+        Imports an existing backend authentication resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.import_backend_auth)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#import_backend_auth)
+        """
+
     def list_backend_jobs(
         self,
         *,
@@ -269,7 +326,9 @@ class AmplifyBackendClient:
         Status: str = None
     ) -> ListBackendJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        Lists the jobs for the backend of an Amplify app.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#list_backend_jobs)
         """
 
@@ -277,13 +336,17 @@ class AmplifyBackendClient:
         self, *, AppId: str, CleanAmplifyApp: bool = None
     ) -> RemoveAllBackendsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        Removes all backend environments from your Amplify project.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_all_backends)
         """
 
     def remove_backend_config(self, *, AppId: str) -> RemoveBackendConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        Removes the AWS resources required to access the Amplify Admin UI.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_backend_config)
         """
 
@@ -296,7 +359,9 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
     ) -> UpdateBackendAPIResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        Updates an existing backend API resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_api)
         """
 
@@ -305,11 +370,13 @@ class AmplifyBackendClient:
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: UpdateBackendAuthResourceConfigTypeDef,
+        ResourceConfig: "UpdateBackendAuthResourceConfigTypeDef",
         ResourceName: str
     ) -> UpdateBackendAuthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        Updates an existing backend authentication resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_auth)
         """
 
@@ -317,7 +384,9 @@ class AmplifyBackendClient:
         self, *, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = None
     ) -> UpdateBackendConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        Updates the AWS resources required to access the Amplify Admin UI.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_config)
         """
 
@@ -331,7 +400,9 @@ class AmplifyBackendClient:
         Status: str = None
     ) -> UpdateBackendJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        Updates a specific job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_job)
         """
 
@@ -339,5 +410,6 @@ class AmplifyBackendClient:
         self, operation_name: Literal["list_backend_jobs"]
     ) -> ListBackendJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
