@@ -71,6 +71,7 @@ __all__ = (
     "GetBackendJobResponseTypeDef",
     "GetBackendResponseTypeDef",
     "GetTokenResponseTypeDef",
+    "ImportBackendAuthResponseTypeDef",
     "ListBackendJobsResponseTypeDef",
     "LoginAuthConfigReqObjTypeDef",
     "PaginatorConfigTypeDef",
@@ -536,6 +537,19 @@ GetTokenResponseTypeDef = TypedDict(
     total=False,
 )
 
+ImportBackendAuthResponseTypeDef = TypedDict(
+    "ImportBackendAuthResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "Error": str,
+        "JobId": str,
+        "Operation": str,
+        "Status": str,
+    },
+    total=False,
+)
+
 ListBackendJobsResponseTypeDef = TypedDict(
     "ListBackendJobsResponseTypeDef",
     {
